@@ -13,6 +13,9 @@
 /* Define to 1 if #include <signal.h> declares struct sigcontext */
 #undef HAVE_SIGCONTEXT
 
+/* Define to the name of the distribution.  */
+#undef PRODUCT
+
 /* Define to 1 if ANSI function prototypes are usable.  */
 #undef PROTOTYPES
 
@@ -25,6 +28,9 @@
 /* Define to 1 if using stack overflow detection.  */
 #undef USE_STACKOVF
 
+/* Define to the version of the distribution.  */
+#undef VERSION
+
 /* Define to 1 for better use of the debugging malloc library.  See 
    site ftp.antaire.com in antaire/src, file dmalloc/dmalloc.tar.gz.  */
 #undef WITH_DMALLOC
